Contributor Code of Conduct
===========================

This project adheres to No Code of Conduct.  We are all adults.  We accept anyone's contributions.  Nothing else matters.

For more information please visit the `No Code of Conduct <https://github.com/domgetter/NCoC>`_ homepage.
